@@ -4,7 +4,12 @@ from __future__ import annotations
 from bleak_retry_connector import close_stale_connections, get_device
 
 from .adv_parser import SwitchbotSupportedType, parse_advertisement_data
-from .const import LockStatus, SwitchbotModel
+from .const import (
+    LockStatus,
+    SwitchbotAccountConnectionError,
+    SwitchbotAuthenticationError,
+    SwitchbotModel,
+)
 from .devices.base_light import SwitchbotBaseLight
 from .devices.bot import Switchbot
 from .devices.bulb import SwitchbotBulb
@@ -24,6 +29,8 @@ __all__ = [
     "parse_advertisement_data",
     "GetSwitchbotDevices",
     "SwitchBotAdvertisement",
+    "SwitchbotAccountConnectionError",
+    "SwitchbotAuthenticationError",
     "ColorMode",
     "LockStatus",
     "SwitchbotBaseLight",
